@@ -33,6 +33,8 @@
 #
 #
 
+from __future__ import with_statement
+
 from deluge._libtorrent import lt
 
 import os
@@ -72,10 +74,15 @@ from deluge.core.eventmanager import EventManager
 from deluge.core.rpcserver import export
 
 class Core(component.Component):
-    def __init__(self, listen_interface=None):
+    def __init__(self, listen_interface=None, read_only_config_keys=None):
         log.debug("Core init..")
         component.Component.__init__(self, "Core")
 
+        # These keys will be dropped from the set_config() RPC and are
+        # configurable from the command-line.
+        self.read_only_config_keys = read_only_config_keys
+        log.debug("read_only_config_keys: %s", read_only_config_keys)
+
         # Start the libtorrent session
         log.info("Starting libtorrent %s session..", lt.version)
 
@@ -131,6 +138,9 @@ class Core(component.Component):
         # New release check information
         self.new_release = None
 
+        # GeoIP instance with db loaded
+        self.geoip_instance = None
+
         # Get the core config
         self.config = deluge.configmanager.ConfigManager("core.conf")
 
@@ -181,8 +191,8 @@ class Core(component.Component):
     def __load_session_state(self):
         """Loads the libtorrent session state"""
         try:
-            self.session.load_state(lt.bdecode(
-                open(deluge.configmanager.get_config_dir("session.state"), "rb").read()))
+            with open(deluge.configmanager.get_config_dir("session.state"), "rb") as _file:
+                self.session.load_state(lt.bdecode(_file.read()))
         except Exception, e:
             log.warning("Failed to load lt state: %s", e)
 
@@ -409,15 +419,18 @@ class Core(component.Component):
     @export
     def pause_all_torrents(self):
         """Pause all torrents in the session"""
-        for torrent in self.torrentmanager.torrents.values():
-            torrent.pause()
+        if not self.session.is_paused():
+            self.session.pause()
+            component.get("EventManager").emit(SessionPausedEvent())
 
     @export
     def resume_all_torrents(self):
         """Resume all torrents in the session"""
-        for torrent in self.torrentmanager.torrents.values():
-            torrent.resume()
-        component.get("EventManager").emit(SessionResumedEvent())
+        if self.session.is_paused():
+            self.session.resume()
+            for torrent_id in self.torrentmanager.torrents:
+                self.torrentmanager[torrent_id].update_state()
+            component.get("EventManager").emit(SessionResumedEvent())
 
     @export
     def resume_torrent(self, torrent_ids):
@@ -434,9 +447,9 @@ class Core(component.Component):
             # Torrent was probaly removed meanwhile
             return {}
 
-        # Get the leftover fields and ask the plugin manager to fill them
+        # Get any remaining keys from plugin manager or 'all' if no keys specified.
         leftover_fields = list(set(keys) - set(status.keys()))
-        if len(leftover_fields) > 0:
+        if len(leftover_fields) > 0 or len(keys) == 0:
             status.update(self.pluginmanager.get_status(torrent_id, leftover_fields))
         return status
 
@@ -499,6 +512,8 @@ class Core(component.Component):
         """Set the config with values from dictionary"""
         # Load all the values into the configuration
         for key in config.keys():
+            if self.read_only_config_keys and key in self.read_only_config_keys:
+                continue
             if isinstance(config[key], unicode) or isinstance(config[key], str):
                 config[key] = config[key].encode("utf8")
             self.config[key] = config[key]
@@ -651,7 +666,9 @@ class Core(component.Component):
         if add_to_session:
             options = {}
             options["download_location"] = os.path.split(path)[0]
-            self.add_torrent_file(os.path.split(target)[1], open(target, "rb").read(), options)
+            with open(target, "rb") as _file:
+                filedump = base64.encodestring(_file.read())
+                self.add_torrent_file(os.path.split(target)[1], filedump, options)
 
     @export
     def upload_plugin(self, filename, filedump):
