@@ -39,6 +39,8 @@
 
 """Main starting point for Deluge.  Contains the main() entry point."""
 
+from __future__ import with_statement
+
 import os
 import sys
 from optparse import OptionParser
@@ -86,7 +88,10 @@ def start_ui():
         help="Sets the log level to 'none', this is the same as `-L none`", action="store_true", default=False)
 
     # Get the options and args from the OptionParser
-    (options, args) = parser.parse_args()
+    if deluge.common.windows_check():
+        (options, args) = parser.parse_args(deluge.common.win32_unicode_argv()[1:])
+    else:
+        (options, args) = parser.parse_args()
 
     # Setup the logger
     if options.quiet:
@@ -166,6 +171,9 @@ this should be an IP address", metavar="IFACE",
         help="Sets the log level to 'none', this is the same as `-L none`", action="store_true", default=False)
     parser.add_option("--profile", dest="profile", action="store_true", default=False,
         help="Profiles the daemon")
+    parser.add_option("--read-only-config-keys", dest="read_only_config_keys",
+        help="List of comma-separated config keys that will not be modified by set_config RPC.",
+        action="store", type="str")
 
     # Get the options and args from the OptionParser
     (options, args) = parser.parse_args()
@@ -173,6 +181,8 @@ this should be an IP address", metavar="IFACE",
     # Setup the logger
     if options.quiet:
         options.loglevel = "none"
+    if options.loglevel:
+        options.loglevel = options.loglevel.lower()
     if options.logfile:
         # Try to create the logfile's directory if it doesn't exist
         try:
@@ -199,12 +209,13 @@ this should be an IP address", metavar="IFACE",
     # Writes out a pidfile if necessary
     def write_pidfile():
         if options.pidfile:
-            open(options.pidfile, "wb").write("%s\n" % os.getpid())
+            with open(options.pidfile, "wb") as _file:
+                _file.write("%s\n" % os.getpid())
 
     # If the donot daemonize is set, then we just skip the forking
     if not options.donot:
         # Windows check, we log to the config folder by default
-        if deluge.common.windows_check() or deluge.common.osx_check():
+        if deluge.common.windows_check():
             open_logfile()
             write_pidfile()
         else:
