@@ -39,6 +39,7 @@
 
 from deluge._libtorrent import lt
 import os
+from deluge.common import is_magnet
 from deluge.log import LOG as log
 from deluge.plugins.pluginbase import CorePluginBase
 import deluge.component as component
@@ -162,7 +163,7 @@ class Core(CorePluginBase):
                 _file = open(filename, "rb")
             elif magnet == True:
                 _file = open(filename, "r")
-            filedump = _file.read()
+            filedump = _file.read().strip()
             if not filedump:
                 raise RuntimeError, "Torrent is 0 bytes!"
             _file.close()
@@ -184,20 +185,25 @@ class Core(CorePluginBase):
             log.warning("Unable to open %s: %s", filename, e)
             raise e
         else:
-            magnets = list(filter(len, _file.readlines()))
+            magnets = list(filter(len, _file.read().splitlines()))
             _file.close()
             if len(magnets) < 2:
                 return
-            n = 0
             path = filename.rsplit(os.sep, 1)[0]
             for magnet in magnets:
+                if not is_magnet(magnet):
+                    log.warning("Found line which is not a magnet: %s", magnet)
+                    continue
+
                 for part in magnet.split('&'):
                     if part.startswith("dn="):
-                        mname = os.sep.join([path, part[3:] + ".magnet"])
-                        break
+                        name = part[3:].strip()
+                        if name:
+                            mname = os.sep.join([path, name + ".magnet"])
+                            break
                 else:
-                    mname = '.'.join([filename, str(n), "magnet"])
-                    n += 1
+                    short_hash = magnet.split("btih:")[1][:8]
+                    mname = '.'.join([os.path.splitext(filename)[0], short_hash, "magnet"])
                 try:
                     _mfile = open(mname, "w")
                 except IOError, e:
@@ -259,12 +265,13 @@ class Core(CorePluginBase):
                 # Skip directories
                 continue
             else:
-                ext = os.path.splitext(filename)[1]
+                ext = os.path.splitext(filename)[1].lower()
                 if ext == ".torrent":
                     magnet = False
                 elif ext == ".magnet":
                     magnet = True
                 else:
+                    log.debug("File checked for auto-loading is invalid: %s", filename)
                     continue
                 try:
                     filedump = self.load_torrent(filepath, magnet)
