@@ -135,6 +135,8 @@ class Core(CorePluginBase):
         :rtype: Deferred
         """
 
+        if not self.config["url"]:
+            return
 
         # Reset variables
         self.filename = None
@@ -425,12 +427,12 @@ class Core(CorePluginBase):
 
     def pause_session(self):
         if not self.core.session.is_paused():
-            self.core.session.pause()
+            self.core.pause_all_torrents()
             self.need_to_resume_session = True
         else:
             self.need_to_resume_session = False
 
     def resume_session(self, result):
-        self.core.session.resume()
+        self.core.resume_all_torrents()
         self.need_to_resume_session = False
         return result
