@@ -127,9 +127,9 @@ class Core(CorePluginBase):
         """
         core_config = deluge.configmanager.ConfigManager("core.conf")
         for setting in CONTROLLED_SETTINGS:
-            component.get("PreferencesManager").do_config_set_func(setting, core_config[setting])
+            core_config.apply_set_functions(setting)
         # Resume the session if necessary
-        component.get("Core").session.resume()
+        component.get("Core").resume_all_torrents()
 
     def do_schedule(self, timer=True):
         """
@@ -153,10 +153,10 @@ class Core(CorePluginBase):
             settings.active_seeds = self.config["low_active_up"]
             session.set_settings(settings)
             # Resume the session if necessary
-            component.get("Core").session.resume()
+            component.get("Core").resume_all_torrents()
         elif state == "Red":
             # This is Red (Stop), so pause the libtorrent session
-            component.get("Core").session.pause()
+            component.get("Core").pause_all_torrents()
 
         if state != self.state:
             # The state has changed since last update so we need to emit an event
