@@ -33,6 +33,8 @@
 #
 #
 
+from __future__ import with_statement
+
 import os
 from HTMLParser import HTMLParser, HTMLParseError
 from urlparse import urljoin, urlparse
@@ -226,7 +228,9 @@ class TrackerIcons(Component):
         if not url:
             url = self.host_to_url(host)
         log.debug("Downloading %s %s", host, url)
-        return download_file(url, mkstemp()[1], force_filename=True)
+        fd, filename = mkstemp(prefix='deluge_ticon.')
+        os.close(fd)
+        return download_file(url, filename, force_filename=True)
 
     def on_download_page_complete(self, page):
         """
@@ -360,7 +364,7 @@ class TrackerIcons(Component):
                 raise InvalidIconError(e)
         else:
             if os.stat(icon_name).st_size == 0L:
-                raise InvalidIconError, "empty icon"
+                raise InvalidIconError("empty icon")
 
         return icon_name
 
